package Bundle::JONASBN;

$VERSION = '0.06';

1;

__END__

=pod

=head1 NAME

Bundle::JONASBN - Collection of modules often used by jonasbn

=head1 SYNOPSIS

    perl -MCPAN -e 'install Bundle::JONASBN'

=head1 CONTENTS

AppConfig

CPAN::Mini

CPAN::Reporter

Class::Accessor

Cwd

DBD::Mock

DBI

Data::Dumper

Data::FormValidator

Date::Calc

DateTime

Devel::Cover

Error

ExtUtils::Install, 1.47

File::Path

File::Slurp

Hash::Merge

JSON

List::MoreUtils

Module::Build, 0.35

Module::Info::File

Module::Load

Params::Validate, 0.85

Perl::Tidy

Pod::Simple::Wiki

Spreadsheet::WriteExcel

Template

Term::ReadLine::Perl

Test::Class

Test::Exception

Test::Kwalitee

Test::MockObject::Extends

Test::More

Test::Perl::Critic

Test::Pod, 1.14

Test::Pod::Coverage, 1.04

Test::Prereq

Tie::IxHash

WWW::Mechanize

WWW::Mechanize::Cached

XML::Simple

YAML

=head1 SEE ALSO

=over

=item * L<Bundle::COG>

=back

=head1 AUTHOR

Jonas B. Nielsen (jonasbn), C<< <jonasbn@cpan.org> >>

=head1 COPYRIGHT & LICENSE

Copyright 2009 Jonas B. Nielsen (jonasbn), All Rights Reserved.

This program is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
